==> nocc-1.8.1.tbz: www/nocc/lang/zh-hans.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: zh-hans.php 1931 2009-07-05 11:07:47Z gerundt $
 */

/** Simplified Chinese (‪中文(简体)‬)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Liu Hong <loyaliu@21cn.com>
 */

$lang_locale = 'zh_CN.UTF-8';
$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%I:%M %p';
$err_user_empty = '用户名为空';
$err_passwd_empty = '密码为空';
$alt_delete = '删除选择的邮件';
$alt_delete_one = '删除邮件';
$alt_new_msg = '新建邮件';
$alt_reply = '回复作者';
$alt_reply_all = '回复所有';
$alt_forward = '转发';
$title_next_msg = '下一个邮件';
$title_prev_msg = '上一个邮件';
$html_on = '打开';
$html_theme_label = '主题';
$html_welcome = '欢迎 %1$s';
$html_login = '登录';
$html_passwd = '密码';
$html_submit = '用户名';
$html_help = '帮助';
$html_server = '服务器';
$html_wrong = '用户名或则密码不正确';
$html_retry = '重试';
$html_view_header = '浏览邮件头';
$html_remove_header = '隐藏邮件头';
$html_inbox = '收件箱';
$html_new_msg = '写邮件';
$html_reply = '回复';
$html_reply_short = 'Re：';
$html_reply_all = '回复所有';
$html_forward = '转发';
$html_delete = '删除';
$html_new = '新';
$html_mark = '置标';
$html_att_label = '附件';
$html_atts_label = '附件';
$html_attach = '附件';
$html_attach_forget = '在发送邮件之前，你必须选一个文件!';
$html_attach_delete = '删除选择';
$html_from = '发件人';
$html_subject = '主题';
$html_date = '日期';
$html_sent = '发送';
$html_size = '大小';
$html_totalsize = '总大小';
$html_bytes = '字节';
$html_filename = '文件名';
$html_nosubject = '没有主题';
$html_send = '发送';
$html_cancel = '取消';
$html_no_mail = '没有邮件.';
$html_logout = '退出';
$html_msg = '邮件';
$html_msgs = '邮件';
$to_empty = ' \'To\' 域不能为空 !';

==> nocc-1.8.3.tbz: www/nocc/lang/zh-hans.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: zh-hans.php 2171 2010-04-08 23:52:07Z siebrand $
 */

/** Simplified Chinese (‪中文(简体)‬)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Liu Hong <loyaliu@21cn.com>
 * @author PhiLiP
 */

$lang_locale = 'zh_CN.UTF-8';
$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%I:%M %p';
$err_user_empty = '用户名为空';
$err_passwd_empty = '密码为空';
$alt_delete = '删除选择的邮件';
$alt_delete_one = '删除邮件';
$alt_new_msg = '新消息';
$alt_reply = '回复作者';
$alt_reply_all = '回复所有';
$alt_forward = '转发';
$title_next_msg = '下一个邮件';
$title_prev_msg = '上一个邮件';
$html_theme_label = '主题';
$html_welcome = '欢迎 %1$s';
$html_login = '登录';
$html_submit = '用户名';
$html_help = '帮助';
$html_wrong = '用户名或则密码不正确';
$html_retry = '重试';
$html_folder_rename = '重命名';
$html_and = '和';
$html_view_header = '浏览邮件头';
$html_remove_header = '隐藏邮件头';
$html_inbox = '收件箱';
$html_new_msg = '写邮件';
$html_reply = '回复';
$html_reply_short = 'Re：';
$html_reply_all = '回复所有';
$html_forward = '转发';
$html_delete = '删除';
$html_new = '新';
$html_mark = '置标';
$html_att_label = '附件';
$html_attach = '附件';
$html_attach_forget = '在发送邮件之前，你必须选一个文件!';
$html_attach_delete = '删除选择';
$html_from = '发件人';
$html_subject = '主题';
$html_date = '日期';
$html_sent_label = '发送';
$html_size = '大小';
$html_totalsize = '总大小';
$html_bytes = '字节';
$html_filename = '文件名';
$html_nosubject = '没有主题';
$html_send = '发送';
$html_cancel = '取消';
$html_no_mail = '没有邮件.';
$html_logout = '退出';
$html_msg = '邮件';
$html_msgs = '邮件';
$to_empty = ' \'To\' 域不能为空 !';
